@@ -48,7 +48,7 @@
 //Declare our constants
 QList<Deinflection::Conjugation> *Deinflection::conjugationList = NULL;
 
-Deinflection::Deinflection( const QString name )
+Deinflection::Deinflection( const QString &name )
 : m_deinflectionLabel( QString() )
 , m_wordType( QString() )
 , m_dictionaryName( name )
@@ -81,7 +81,7 @@ EntryList* Deinflection::search( const DictQuery &query, const QVector<QString>
   edictTypesList.append( EdictFormatting::Adjectives );
   edictTypesList.append( EdictFormatting::Verbs      );
 
-  QString edictTypes = edictTypesList.join( "," );
+  QString edictTypes = edictTypesList.join( QStringLiteral(",") );
 
   foreach( const QString &item, preliminaryResults )
   {
@@ -168,7 +168,7 @@ bool Deinflection::load()
 
   conjugationList = new QList<Conjugation>;
 
-  QString vconj = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kiten/vconj");
+  QString vconj = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kiten/vconj"));
   
   //Find the file
   if ( vconj.isEmpty() )
@@ -230,7 +230,7 @@ bool Deinflection::load()
   return true;
 }
 
-inline EntryEdict* Deinflection::makeEntry( QString entry )
+inline EntryEdict* Deinflection::makeEntry( const QString &entry )
 {
   return new EntryEdict( m_dictionaryName, entry );
 }
