@@ -47,7 +47,7 @@ RadSelect::RadSelect()
   // accept dnd
   setAcceptDrops( true );
   setCentralWidget( m_view );  //This is the main widget
-  setObjectName( QLatin1String( "radselect" ) );
+  setObjectName( QStringLiteral( "radselect" ) );
 
   KStandardAction::quit( this, SLOT(close()), actionCollection() );
   KStandardAction::preferences( this, SLOT(optionsPreferences()), actionCollection() );
@@ -58,11 +58,11 @@ RadSelect::RadSelect()
   // automatically save settings if changed: window size, toolbar
   // position, icon size, etc.  Also to add actions for the statusbar
   // toolbar, and keybindings if necessary.
-  setupGUI( Default, "radselectui.rc" );
+  setupGUI( Default, QStringLiteral("radselectui.rc") );
 
   // allow the view to change the statusbar
-  connect( m_view, SIGNAL(signalChangeStatusbar(QString)),
-             this,   SLOT(changeStatusbar(QString)) );
+  connect( m_view, &RadSelectView::signalChangeStatusbar,
+             this,   &RadSelect::changeStatusbar );
 
   if( ! QDBusConnection::sessionBus().isConnected() )
   {
@@ -71,13 +71,13 @@ RadSelect::RadSelect()
   }
   else
   {
-    m_dbusInterface = new QDBusInterface(   "org.kde.kiten", "/", ""
+    m_dbusInterface = new QDBusInterface(   QStringLiteral("org.kde.kiten"), QStringLiteral("/"), QLatin1String("")
                                           , QDBusConnection::sessionBus() );
   }
 
   // connect the search signal from the m_view with our dbus routines
-  connect( m_view, SIGNAL(kanjiSelected(QStringList)),
-             this,   SLOT(sendSearch(QStringList)) );
+  connect( m_view, &RadSelectView::kanjiSelected,
+             this,   &RadSelect::sendSearch );
 }
 
 RadSelect::~RadSelect()
@@ -93,7 +93,7 @@ void RadSelect::changeStatusbar( const QString& text )
 
 void RadSelect::dragEnterEvent( QDragEnterEvent *event )
 {
-  if ( event->mimeData()->hasFormat( "text/plain" ) )
+  if ( event->mimeData()->hasFormat( QStringLiteral("text/plain") ) )
   {
     event->acceptProposedAction();
   }
@@ -101,7 +101,7 @@ void RadSelect::dragEnterEvent( QDragEnterEvent *event )
 
 void RadSelect::dropEvent( QDropEvent *event )
 {
-  QByteArray qba = event->mimeData()->data("text/plain");
+  QByteArray qba = event->mimeData()->data(QStringLiteral("text/plain"));
   if ( qba.size() > 0 )
   {
     loadSearchString( qba );
@@ -113,24 +113,24 @@ void RadSelect::loadSearchString( const QString &searchString )
   m_currentQuery = searchString;
   changeStatusbar( searchString );
   //TODO: Parse the strokes
-  QString strokeStr = m_currentQuery.getProperty( "S" );
+  QString strokeStr = m_currentQuery.getProperty( QStringLiteral("S") );
   int min = 0;
   int max = 0;
-  m_view->loadRadicals( m_currentQuery.getProperty( "R" ), min, max );
+  m_view->loadRadicals( m_currentQuery.getProperty( QStringLiteral("R") ), min, max );
 }
 
 void RadSelect::optionsPreferences()
 {
-  if( KConfigDialog::showDialog( "settings" ) )
+  if( KConfigDialog::showDialog( QStringLiteral("settings") ) )
   {
     return;
   }
 
-  KConfigDialog *dialog = new KConfigDialog( this,"settings", RadSelectConfigSkeleton::self() );
+  KConfigDialog *dialog = new KConfigDialog( this,QStringLiteral("settings"), RadSelectConfigSkeleton::self() );
   QWidget *preferences = new QWidget();
   Ui::radselectprefdialog layout;
   layout.setupUi( preferences );
-  dialog->addPage( preferences, i18n( "Settings" ), "help-contents" );
+  dialog->addPage( preferences, i18n( "Settings" ), QStringLiteral("help-contents") );
   connect( dialog, SIGNAL(settingsChanged(QString)),
            m_view,   SLOT(loadSettings()) );
   dialog->show();
@@ -167,7 +167,7 @@ void RadSelect::sendSearch( const QStringList& kanji )
 
   if( m_dbusInterface && m_dbusInterface->isValid() )
   {
-    QDBusMessage reply = m_dbusInterface->call(  QLatin1String( "searchTextAndRaise" )
+    QDBusMessage reply = m_dbusInterface->call(  QStringLiteral( "searchTextAndRaise" )
                                                , m_currentQuery.toString() );
     if( reply.type() == QDBusMessage::ErrorMessage )
     {
